@@ -25,14 +25,14 @@ from megadetector.utils.ct_utils import sort_dictionary_by_value
 from megadetector.utils.ct_utils import sort_dictionary_by_key
 from megadetector.utils.ct_utils import invert_dictionary
 
-from megadetector.utils.wi_utils import clean_taxonomy_string
-from megadetector.utils.wi_utils import taxonomy_level_index
-from megadetector.utils.wi_utils import taxonomy_level_string_to_index
+from megadetector.utils.wi_taxonomy_utils import clean_taxonomy_string
+from megadetector.utils.wi_taxonomy_utils import taxonomy_level_index
+from megadetector.utils.wi_taxonomy_utils import taxonomy_level_string_to_index
 
-from megadetector.utils.wi_utils import non_taxonomic_prediction_strings
-from megadetector.utils.wi_utils import human_prediction_string
-from megadetector.utils.wi_utils import animal_prediction_string
-from megadetector.utils.wi_utils import blank_prediction_string # noqa
+from megadetector.utils.wi_taxonomy_utils import non_taxonomic_prediction_strings
+from megadetector.utils.wi_taxonomy_utils import human_prediction_string
+from megadetector.utils.wi_taxonomy_utils import animal_prediction_string
+from megadetector.utils.wi_taxonomy_utils import blank_prediction_string # noqa
 
 
 #%% Options classes
@@ -505,7 +505,6 @@ def _smooth_classifications_for_list_of_detections(detections,
 
             # If we're doing taxonomic processing, at this stage, don't turn children
             # into parents; we'll likely turn parents into children in the next stage.
-
             if process_taxonomic_rules:
 
                 most_common_category_description = \
@@ -612,10 +611,22 @@ def _smooth_classifications_for_list_of_detections(detections,
                 if len(category_description_candidate_child) == 0:
                     continue
 
+                # This handles a case that doesn't come up with "pure" SpeciesNet results;
+                # if two categories have different IDs but the same "clean" description, this
+                # means they're different common names for the same species, which we use
+                # for things like "white-tailed deer buck" and "white-tailed deer fawn".
+                #
+                # Currently we don't support smoothing those predictions, because it's not a
+                # parent/child relationship.
+                if category_description_candidate_child == \
+                    category_description_this_classification:
+                    continue
+
                 # As long as we're using "clean" descriptions, parent/child taxonomic
                 # relationships are defined by a substring relationship
                 is_child = category_description_this_classification in \
                     category_description_candidate_child
+
                 if not is_child:
                     continue
 
@@ -1089,7 +1100,8 @@ def restrict_to_taxa_list(taxa_list,
                           input_file,
                           output_file,
                           allow_walk_down=False,
-                          add_pre_filtering_description=True):
+                          add_pre_filtering_description=True,
+                          allow_redundant_latin_names=False):
     """
     Given a prediction file in MD .json format, likely without having had
     a geofence applied, apply a custom taxa list.
@@ -1112,6 +1124,10 @@ def restrict_to_taxa_list(taxa_list,
         add_pre_filtering_description (bool, optional): should we add a new metadata
             field that summarizes each image's classifications prior to taxonomic
             restriction?
+        allow_redundant_latin_names (bool, optional): if False, we'll raise an Exception
+            if the same latin name appears twice in the taxonomy list; if True, we'll
+            just print a warning and ignore all entries other than the first for this
+            latin name
     """
 
     ##%% Read target taxa list
@@ -1126,11 +1142,14 @@ def restrict_to_taxa_list(taxa_list,
     taxa_list = [s for s in taxa_list if len(s) > 0]
 
     target_latin_to_common = {}
+
     for s in taxa_list:
+
         if s.strip().startswith('#'):
             continue
         tokens = s.split(',')
-        assert len(tokens) <= 2
+        # We allow additional columns now
+        # assert len(tokens) <= 2
         binomial_name = tokens[0]
         assert len(binomial_name.split(' ')) in (1,2,3), \
             'Illegal binomial name in species list: {}'.format(binomial_name)
@@ -1138,9 +1157,17 @@ def restrict_to_taxa_list(taxa_list,
             common_name = tokens[1].strip().lower()
         else:
             common_name = None
-        assert binomial_name not in target_latin_to_common
+        if binomial_name in target_latin_to_common:
+            error_string = 'scientific name {} appears multiple times in the taxonomy list'.format(
+                    binomial_name)
+            if allow_redundant_latin_names:
+                print('Warning: {}'.format(error_string))
+            else:
+                raise ValueError(error_string)
         target_latin_to_common[binomial_name] = common_name
 
+    # ...for each line in the taxonomy file
+
 
     ##%% Read taxonomy file
 
